@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: texmath
-version: 0.8.6.1
-id: texmath-0.8.6.1-5f9e05ceca1cc643ef8bc76de94907d1
-key: texma_70gVuLSWKMaHtCmnebC0QD
+version: 0.8.6.2
+id: texmath-0.8.6.2-095c538c216585563c12e2c8d1233f7e
+key: texma_Iw7O8nvR2JQEjqbnrNNStw
 license: GPL
 maintainer: jgm@berkeley.edu
 stability: Experimental
@@ -56,15 +56,15 @@ exposed-modules:
 hidden-modules: Text.TeXMath.Compat Text.TeXMath.Shared
                 Text.TeXMath.TeX Paths_texmath
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/texmath-0.8.6.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/texmath-0.8.6.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/texmath-0.8.6.1
-hs-libraries: HStexmath-0.8.6.1-70gVuLSWKMaHtCmnebC0QD
+import-dirs: /usr/lib/ghc-7.10.3/site-local/texmath-0.8.6.2
+library-dirs: /usr/lib/ghc-7.10.3/site-local/texmath-0.8.6.2
+data-dir: /usr/share/arm-linux-ghc-7.10.3/texmath-0.8.6.2
+hs-libraries: HStexmath-0.8.6.2-Iw7O8nvR2JQEjqbnrNNStw
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    pandoc-types-1.16.1-5c682c2b5cffa962280d4abd090bac44
+    pandoc-types-1.16.1-30bcf2ba2a8f2fe5e0ad6c109c33aa1e
     parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
     syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
     xml-1.3.14-6291d85df68e094bfca87f33fea8b24c
